"""ob12

Revision ID: 7228a3a08576
Revises: 2cad88d938f1
Create Date: 2023-01-16 17:15:05.640599

"""
import sqlalchemy as sa
import sqlmodel
from alembic import op
from sqlmodel import Session, select

from nonebot_plugin_chatrecorder import plugin_config
from nonebot_plugin_chatrecorder.model import MessageRecord

# revision identifiers, used by Alembic.
revision = "7228a3a08576"
down_revision = "2cad88d938f1"
branch_labels = None
depends_on = None


def check_config():
    """如果没有设置 chatrecorder_record_migration_bot_id，那么就不允许迁移"""
    with Session(op.get_bind()) as session:
        select_statement = select(MessageRecord.id)  # type: ignore
        result = session.exec(select_statement)
        messages = result.all()
        if messages and plugin_config.chatrecorder_record_migration_bot_id is None:
            raise ValueError("你需要设置 chatrecorder_record_migration_bot_id 以完成迁移")


def set_default_value():
    bot_id = plugin_config.chatrecorder_record_migration_bot_id or ""
    with Session(op.get_bind()) as session:
        select_statement = select(MessageRecord)
        result = session.exec(select_statement)
        for record in result:
            record.bot_type = "OneBot V11"
            record.bot_id = bot_id
            if record.user_id == bot_id:
                record.type = "message_sent"
            if record.detail_type == "private":
                record.group_id = None
            session.add(record)
        session.commit()


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table(
        "nonebot_plugin_chatrecorder_messagerecord", schema=None
    ) as batch_op:
        batch_op.alter_column(
            "id", existing_type=sa.INTEGER(), nullable=False, autoincrement=True
        )
        batch_op.alter_column("alt_message", new_column_name="plain_text")
    check_config()
    op.add_column(
        "nonebot_plugin_chatrecorder_messagerecord",
        sa.Column("bot_type", sqlmodel.sql.sqltypes.AutoString(), nullable=True),
    )
    op.add_column(
        "nonebot_plugin_chatrecorder_messagerecord",
        sa.Column("bot_id", sqlmodel.sql.sqltypes.AutoString(), nullable=True),
    )
    op.add_column(
        "nonebot_plugin_chatrecorder_messagerecord",
        sa.Column("guild_id", sqlmodel.sql.sqltypes.AutoString(), nullable=True),
    )
    op.add_column(
        "nonebot_plugin_chatrecorder_messagerecord",
        sa.Column("channel_id", sqlmodel.sql.sqltypes.AutoString(), nullable=True),
    )
    set_default_value()
    with op.batch_alter_table(
        "nonebot_plugin_chatrecorder_messagerecord", schema=None
    ) as batch_op:
        batch_op.alter_column(
            "bot_type",
            existing_type=sa.VARCHAR(),
            nullable=False,
        )
        batch_op.alter_column(
            "bot_id",
            existing_type=sa.VARCHAR(),
            nullable=False,
        )

    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table(
        "nonebot_plugin_chatrecorder_messagerecord", schema=None
    ) as batch_op:
        batch_op.alter_column(
            "id", existing_type=sa.INTEGER(), nullable=True, autoincrement=True
        )
        batch_op.alter_column("plain_text", new_column_name="alt_message")
        batch_op.drop_column("channel_id")
        batch_op.drop_column("guild_id")
        batch_op.drop_column("bot_id")
        batch_op.drop_column("bot_type")

    # ### end Alembic commands ###
